import { createEntityAdapter, createSlice } from "@reduxjs/toolkit";
import { Todo } from "@src/core/entities/todo";
import { AppState } from "@src/infrastructure/store";

export const todosAdapter = createEntityAdapter<Todo>({
  selectId: (todo) => todo.id,
  sortComparer: (a, b) => a.title.localeCompare(b.title),
});

export const todosSlice = createSlice({
  name: "todo",
  initialState: todosAdapter.getInitialState(),
  reducers: {
    todoAdded: todosAdapter.addOne,
    todosReceived(state, action) {
      todosAdapter.setAll(state, action.payload.todos);
    },
  },
});

export const todosSelectors = todosAdapter.getSelectors<AppState>(
  (state) => state.todos
);
